Mozilla .lang files — Translate Toolkit 3.1.0 documentation

Translate Toolkit 3.1.0

- Site
  - Features
  - Installation
  - Converters
  - Tools
  - Scripts
  - Use Cases
  - Supported formats
  - Translate Styleguide
  - Documentation
  - Building
  - Testing
  - Command Line Functional Testing
  - Contributing
  - Translate Toolkit Developers Guide
  - Making a Translate Toolkit Release
  - Deprecation of Features
  - Release Notes
  - History of the Translate Toolkit
  - License
  - API
- Page
  - Mozilla .lang files
    - References
- « .NET Resource files (.resx)
- TMX »

# Mozilla .lang files

Mozilla’s custom .lang format is used for some of their websites.

## References

- .lang specification

- www.mozilla.org repository of translations